# Dev Notes

:warning: **Attention:** Hey Reader! Any line that begins like this, is a "comment" that does not impact the rules; these are just left here as notes to myself for later. I've also included :memo: **Developer Notes**, which are more like commentary regarding the design process - these are open for feedback, along with the rules and prose.

# Introduction

:memo: **Developer Note:** Add this to the introduction: Curses and Blessings is a game that focuses largely on exploration and problem solving. While combat can and does happen, it is not the focus.

:memo: **Developer Note:** If two parties meet, they could have two super smart characters duel via chess to see who climbs the chain first. Reputation can also be a big influence in the game's world.

:question: **TODO:** introductions tend to be written late in development

:question: **TODO:** TOC - for now, use VSCode's outline panel.

# The Setting

This game's world is centered around Tiere, The Sacred Mountain. Jutting out of an otherwise flat landscape, the mountain can be seen clearly from a great distance in all directions. This has given rise to a multitude of myths and legends centered on the mountain, and has attracted people seeking to climb it for thousands of years.

The history of the mountain is long and storied; the oldest known tales liken it to a great beast emerging from the oceans, walking to its current position and falling asleep. Other, more credible stories tell of ancient and powerful artifacts from long-forgotten kingdoms buried deep within; some of these artifacts are believed to be so powerful, that they could tip the balance of power between nations.

Over time a city named Vorland grew at the mountain's foot; it now houses a thriving culture dedicated to exploring and exploiting the mountain's riches. Foremost among its factions is the Mountaineer's Guild - a branch of the administration that issues licenses to climbers, and handles the processing and sale of recovered artifacts.

It is from here that your game begins.

## Tiere, the Sacred Mountain

:memo: **Developer Notes:** I wonder if I should specify exact altitudes, or just leave it for the player's imagination?

The mountain's slopes are traditionally divided into seven distinct areas, known as "elevations". These are:

* [Vorland, The City Below](#vorland-the-city-below)
* [1st Elevation - Foothills and Forests](#foothills-and-forests)
* [2nd Elevation - Dotted Caves](#dotted-caves)
* [3rd Elevation - Gambler's Bluff](#gamblers-bluff)
* [4th Elevation - Mycelia Jungles](#mycelia-jungles)
* [5th Elevation - Kingdom of Failures](#kingdom-of-failures)
* [6th Elevation - Frigid Plateau](#frigid-plateau)
* [7th Elevation - Chained Apex](#chained-apex)

## Vorland, The City Below

Vorland is a historic resource town that survives by recovering artifacts from the mountain, and selling them across the continent. Built into a valley among the foothills, and marked by the Contrast River, the sight of common-class artifacts is a part of daily life.

Due to its proximity to the 1st Elevation, a prominent stonework wall marks the historical edge of the city's limits; unfortunately, it doesn't always stop strange beasts from wandering the streets at night.

:memo: **Developer Note:** The Contrast River carries fresh water from the 2nd Elevation, and the riverbed is covered in multicolored stones, hence the name. These stones are pretty, but otherwise mundane.

## Foothills and Forests

A dense, but navigable forest that covers the lowest parts of the ascent. The flora here seems to grow unnaturally fast, so any attempt at establishing a permanent road has met with failure. The angle of the slopes averages about 60 degrees, further impeding all but the simplest of construction efforts.

## Dotted Caves

A series of natural and unnatural cuts into the mountain can be found here. The lowest cave openings mark the beginning of the 2nd Elevation. The forests continue up the surface, often obscuring smaller openings, which pose a hazard to those who climb without caution.

The cave systems have yet to be fully explored and mapped due to the dangerous creatures and precarious terrain within; the river that sustains the city below originates from one of the larger openings. The name of this Elevation comes from the unusual rocks and stones found here, which bear an apparent speckled sheen when reflecting light.

## Gambler's Bluff

The 3rd Elevation is a sheer vertical cliff face, which abruptly bursts forth from the ground below. The surface of the bluff is covered with grips and handholds, many of which are no larger than your fingertips. The bluff is pockmarked by narrow tunnels, sometimes called "pigeonholes", dug into the rock face by large birds of prey called "fortner".

Choosing the right pigeonhole to rest in is a gamble, as these are the fortner's nesting places, and choosing an occupied one will result in sudden and violent ejection by the occupants. Many abandoned pigeonholes are connected within the mountain's bulk, and can be traversed, sometimes granting a dark and cramped, but safer route upwards.

:memo: **Developer Note:** The fortner are endemic to the mountain. Up to a third of the pigeonholes are occupied.

## Mycelia Jungles

A vast ecosystem of fungi and other plant matter covers the 4th Elevation. Some of these biological structures are strong enough to support their own weight, and more, while jutting out above the cliff's edge, creating a larger walkable area than what would be expected.

Many creatures endemic to the mountain have evolved to thrive in this high altitude ecosystem, or to venture in for food. While it's possible to consume some of the more benign growths here, the environment is just as likely to consume you in return.

A word of warning: Great care must be taken not to become infected; there are recorded instances of climbers who, after reaching this Elevation and returning to the city below, were totally unperturbed by their bodies being rebuilt or replaced by fungal parasites.

## Kingdom of Failures

High above the clouds, beyond the view of even the best looking glasses, lies the dilapidated remains of past civilizations, Seemingly built into and on top of each other in a dense network of twisting rooms, corridors and bridges. At least three distinct architectural styles have been identified, with many others hinted at having been scrapped for building materials.

Among these ruins live small bands of climbers who, for one reason or another, can't or won't ascend any further. Subsisting on materials grown here or gathered from the jungle, these groups vie for valuable and powerful artifacts buried in the mountain's core.

## Frigid Plateau

The top two Elevations remain hidden in cloud cover at all times; this seemingly unnatural phenomenon also prevents climbers from returning from beyond this point. The only information we've been able to ascertain comes from written reports, secured within rocket-like projectiles, fired through gaps in the cloud barrier by the few brave - or suicidal - souls that enter.

According to the reports, the already cold air becomes frigid, plant life vanishes, and snow drifts hide deep crevasses that swallow people whole.

The most notable feature of this Elevation has only a handful of reliable accounts within the last four centuries - the peak of the mountain has been sliced off, as if by a blade - the exposed rock is smooth to the touch, and seems to extend from one side of the plateau to the other.

## Chained Apex

Visibility on the plateau is poor to non-existent due to cloud cover and snow storms. Among those that wander here, only a lucky few have managed to find the chains - massive metallic structures resembling links in a chain, with one end reaching into the heavens, and the other embedded deep into the rock below.

These chains, measured at two arm spans thick, seem to move over time, as though whatever they tether to the mountain is drifting with the winds. While attempts at climbing them have reportedly been made, no news of success or failure has ever reached the city below.

# Character Creation

:memo: **Developer Note:** I am deliberately leaving the player characters' backgrounds as blank slates for the time being, as focusing on the core mechanics comes first. This may be expanded more in later iterations.

When playing this game, each player adopts the identity of a climber. Each climber has a past, a reason to be here, and an ultimate goal. What these are is up to the player's imagination.

When you begin your campaign, each character begins with four core attributes, some initial skill points, and a beginner's pack to get you going.

## Core Attributes

Each character begins with a set of four attributes, called the Core Attributes. An "attribute" is simply the name of a value belonging to your character - more attributes can be gained, and existing ones improved as you progress play. The current value of an attribute can be reduced by various means, or restored to its maximum value, usually by resting.

The Core Attributes are:

| Name | Value | Description |
| --- | :---: | --- |
| Health | 10/10 | Representing your physical wellness, and is depleted by injuries. |
| Stamina | 10/10 | The amount of energy you have, which can be spent to perform strenuous tasks. |
| Fortitude | 10/10 | How resistant you are to the negative effects of climbing, altitude sickness, and other environmental effects. |
| Obsession | 10/10 | Represents your fixation with the mountain, and how well you can use artifacts. |

Each of the core attributes begins at 10/10 (current/maximum); any additional attributes that you don't have yet are considered to be 0/0.

## Initial Skill Points

When building a new character, you begin with 20 unallocated skill points, with more earned as you play. You can spend these while resting to buy new skills, or level up existing skills; any skills you don't have are considered level 0.

To buy a new skill or level up an existing one, you must first meet the listed prerequisites (including any previous levels), and spend skill points equal to the new level. (e.g. To buy a skill at level 4, you must spend a total of 10 skill points.) Unspent skill points can be saved for later.

There is an additional restriction during character creation; before your character begins their first ascent, they are limited to a maximum of 5 skills. After they begin, this restriction is immediately removed.

## Beginner's Pack

Finally, after creating a new character, they begin with a set of standard issue items granted by the Mountaineer's Guild, including casual clothes, climbing clothes, climbing gloves, solid shoes and a basic hard hat - and most importantly, a basic climbing bag with a capacity of 10 item slots.

The local currency is a small copper coin called an "az", ten of which makes 1 silver "denaz". Each character begins the game with 100az, and can buy extra items from the markets. A full list of items can be found in [Common Items For Purchase](#common-items-for-purchase).

:memo: **Developer Note:** The limited pack space is intended to encourage using consumable items. It also doubles as an interesting choice for the player.

:memo: **Developer Note:** Copper vs. silver coins, as well as other coins from across the continent, are supposed to show how widely people travel to climb the mountain. Some coins in circulation are more valuable in some places than others. For now though, let's keep it simple, with only one currently value, and revisit it later.

# Core Gameplay

The core gameplay of Curses & Blessings is a combination of roleplay scenarios, combat encounters, and skill challenges.

:memo: **Developer Note:** Critical Ranges and Limit Breaks (or bloodied status) are an interesting idea that I toyed with previously, and I do plan on returning to it to see how well they work, once the core rules have ossified.

## Roleplay Scenarios

:question: **TODO:** Detail this - for now, the first playtesters know what RP is.

## Skill Challenges

At certain points during the campaign, you will be presented with an obstacle or series of obstacles that requires rolling a d20, and scoring equal or above a certain target value - these are called "Skill Challenges". When performing a Skill Challenge, you may select a skill your character knows that could reasonably contribute towards overcoming that obstacle; either adding the current level of that skill to your roll, or using some listed effect.

On a success, you overcome whatever task you were attempting; on a failure, you lose your choice of either one point of Stamina, or one point from that skill's linked attribute. You cannot use a skill if the linked attribute has already been reduced to 0.

When you fail a Skill Challenge, you may choose to "exert" your character once by spending one point of Stamina to re-roll that attempt - if you do, you must take the new result. If your Stamina (or Fortitude) ever reaches 0 (either by accident or deliberately), you become [Fatigued](#resting-and-fatigue).

## Combat Encounters

:memo: **Developer Note:** Consider advantage & disadvantage.

When you find yourself fending off an attacker, or as an attacker, all participating creatures are said to be in combat. Combat is broken down into a series of rounds, during which each combatant will have the opportunity to act.

At the beginning of each round, all combatants must roll a d20 to determine their turn order, re-rolling to break ties. Then, starting from the first combatant in the turn order, they may either attack with a melee or ranged weapon, maneuver around the environment for a better vantage point, or they may attempt to flee the battle.

If attacking a target, you must first perform a hit roll by rolling a d20, with the target's current Fortitude as the target value. On a success, you may perform a wound roll by rolling dice based on the weapon or item you are using (attacking while unarmed has a wound roll of 1d6).

When you succeed a hit roll, if you rolled a 20 (the maximum value), this is called a critical hit. Unless the effects of a critical hit are listed for the weapon or item you used, the damage dealt by this attack is doubled. When you fail a hit roll, you may choose to "exert" your character once by spending one point of Stamina to re-roll that attempt - if you do, you must take the new result.

The damage dealt by the wound roll is subtracted from the target's Health, and the target's Fortitude is reduced by 1. Just as with Skill Challenges, if a combatant's Stamina or Fortitude ever reaches 0, they become [Fatigued](#resting-and-fatigue). Likewise, if their Health reaches 0, they [die](#dying-and-death).

If you decide to maneuver around the environment on your turn, you can position yourself somewhere that is easier to attack from next round, or places you somewhere out of danger. Sometimes, you may even be able to escape from combat, while abandoning your party members.

## Climbing

Climbing such an immense mountain is no small task. Many people can dedicate their lives to mountaineering, and still not have explored the entirety of even the lower elevations. Add to that, the many dangers and challenges encountered, and it's easy to see why only the bravest - or craziest - are up to the challenge.

Some well worn pathways are relatively easier to traverse, taking only a set amount of time, while other uncharted paths will present unpredictable and sometimes insurmountable obstacles.

If you choose to follow the established paths, the time taken on each elevatiion is as follows:

* 1st Elevation - 1 Day
* 2nd Elevation - 2 Days
* 3rd Elevation - 4 Days

For the 3rd Elevation specifically, there are no permanent outposts or resting places, nor are there members of the Mountaineering Guild to guide you up or down - from this point forward, you are on your own.

When returning from a climb, you may be weighed down by discoveries, or injuries, and are more susceptible to those who would take advantage of you. Thankfully, the outposts on the first and second elevations can act as rest areas, and may sometimes offer assitance for your return, for a price.

:question: **TODO:** Add the price for the assitance.

:memo: **Developer Note:** The outpost leader has a secret task, in addition to assisting climbers who pass by - if an artifact with the capability of destablilizing or destroying the power of the Mountaineering Guild, or of the Mountain itself is found, the leader must, at their discretion, suppress or destroy that artifact.

## Mountain Sickness

It's a well known phenomenon across the continent that climbing mountains can cause various maladies. The lower concentrations of oxygen, as well as the lower pressure inherent to higher altitudes, causes a series of nausiating to debilitating effects.

For Tiere, The Sacred Mountain, be it providence or coincidence, it seems that each elevation aligns with the worsening of symptoms. At the dawn of each day, each player must perform a [skill challenge](#skill-challenges) to avoid altitude sickness, depending on which elevation they've reached:

| Elevation | Target | Effect on Failure |
| --- | --- | --- |
| Foothills | No challenge needed. | - | - |
| Dotted Caves | 12 | Lose 1 Fortitude. |
| Gambler's Bluff | 14 | Lose 1 Fortitude, need to spend 1 segment of time recovering. |
| Mycelia Jungles | 16 | Lose 1 Fortitude, then make another skill challenge with a target of 16, and on a failure, you become Fatigued. |
| Kingdom of Failures | 16 | Lose 1 Stamina and 1 Fortitude, and all rolls for this day receive a -1 penalty. |
| Frigid Plateau | - | - |
| Chained Apex | - | - |

Multiple skills are available for purchase which alleviate these symptoms, or at a minimum, makes the effects barable. Other medicinal solutions exist, such as sunberries, which grow across the first five elevations.

:question: **TODO:** Skills that make it easier have a prerequisite like: Reach elevation X and return to the city.

## Resting and Fatigue

:memo: **Developer Note:** When writing this, I wanted the full effect of fatigue to be reducing the damage dealt by half, reducing movement speed by half, and making it hard or impossible to move up or down the mountain. However, since I haven't written the parts concerning movement and ascension yet, I'll leave the effects of fatigue as a slightly wrong placeholder for the time being - I want to get the draft functioning first, so I can test it, rather than getting everything right on the first pass.

Climbing the mountain can be taxing on both the mind and body - if your character's Stamina or Fortitude attributes ever reaches zero, that character becomes Fatigued. While your character has Fatigued condition, any combat damage they deal is reduced by half (rounded up), and any combat damage they receive is doubled.

While on the mountain, if you find a safe location, you may decide to rest. Resting will restore your attributes and allow you to use items, and sleep.

While Fatigued, your attributes will not be restored by resting until the Fatigued status is alleviated. To do this, you must sleep for at least 2 blocks of time (six hours) without a break. Once you are no longer Fatigued, you may continue to rest. If you are not Fatigued, you can restore your attributes by resting for at least 1 block of time (3 hours).

## Dying and Death

Your character's health attribute represents their physical fitness - as they accumulate injuries or illnesses, their health attribute will be directly impacted. If your character's health attribute is ever reduced to 0 or below, they die.

Even before your character's health drops to 0, some situations my cause potentially debilitating conditions, such as becoming poisoned or losing a limb, requiring some kind of prosthetic to continue.

:memo: **Developer Note:** Poisons and prosthetics are possible future mechanics. I'm also considering other generic conditions like blindness and deafness. Exactly what effect these will have, I haven't decided yet - they may impact more than just your attributes.

## Distances and Measurements

In this game, distances are abstracted, to allow for ease of gameplay - the four ways of determining distance are Touch, Close, Near and Far. Anything you are holding is within Touch distance. If something is close by, then you could touch it with an outstretched arm with only one or two steps. Something that is Near by is easily reachable, and would be able to hear you if you spoke. Anything outside of this is Far away.

Any items, weapons or artifacts that don't list an effective range would generally have a range of touch.

## The Passage of Time

For climbers on the mountain, keeping track of the time of day is important, as different and dangerous creatures may be active at different times.

Rather than following the traditional 24-hour system, one full day on the mountain is divided into 8 blocks of roughly equal size, usually depicted as a circle divided into 8 segments. Closewise from the top are midday, dusk, midnight and dawn, marking the four cardinal points on the circle.

# Common Items For Purchase

For those who live and work in Vorland, the sight of pilgrims, adventurers and fortune seekers is an everyday occurrence. The local coinage is often mixed with coins from across the continent, or may bear markings of old - but they are all welcomed by the city's businesses.

Below is a table of the most commonly purchased maintaineering gear. While not an exhaustive list of what's available, these items can be purchased with very little hassle. Items listed as "Petty" are normally attached to the outside of your pack or to your body, so they don't consume inventory space. Items listed as "Bulky" are larger than normal, so they take two inventory spaces to carry.

| Item | Cost | Description |
| --- | ---: | --- |
| Food Rations | 5az | Dry, dull tasting but nutritious, it's made up of nuts and common fruits, dried and condensed into an easy to hold bar shape. Enough for one meal. |
| Cooking and Cutlery Gear | 30az | Ideal for preparing meals while roughing it, this contains several small pots, cups, multiuse cutlery, and a flimsy stand for a campfire. |
| Sleeping Set | 50az | Bulky. A thin but warm blanket, and a soft but durable mat with a small pillow sewn onto one end. |
| Small Knife and Sheath | 10az | Weapon (2d6), Petty. A small but sharp knife, and a sheath that attaches to a belt. |
| Small Folding Pickaxe | 30az | Weapon (2d6). A small but sturdy pickaxe that can be folded away. |
| Small Compass | 40az | Petty. A small compass, its magnetic needle points north. |
| 10m Rope | 10az | A good solid length of rope, sold in multiples of 10 meters. Can be tied to a piton embedded in a wall. |
| Piton Bundle | 20az | A spike with a loop on the other end, sold in bundles of three. Each bundle of up to three pitons consumes one inventory slot. |
| Glowstone Lantern | 45az | Produces a moderate amount of light. Usually safe to use, as long as the glowstone within is handled carefully. |
| 2m Bandages | 10az | Essential for emergencies, it can be used to bind or staunch a wound, or as a makeshift sling for a broken limb. |
| Soothing Salve | 15az | A pale viscous cream derived from a fungus, used for pain relief. Apply no more than once per segment of time to a wound to restore 1d6 Health. Does not heal broken bones or restore lost body parts, 6 uses. |
| Cold Weather Clothes | 1000az | Highly durable warm weather clothing, effectively essential at higher altitudes. Available in various sizes. |
| Sketchbook and Pencil | 25az | A simple but durable notebook, with pages ideal for sketching or taking notes. Comes with a matching pencil. |
| Small Candle Bundle | 20az | A small, portable candle that produces a weak light, but last for a few hours. Comes with a small sparkstone to light them. Each bundle of up to ten candles consumes one inventory slot. |

:question: **TODO:** Tie a mechanical bonus to these, where needed

# Artifacts

:question: **TODO:** Empty - We're here for the Phat Lute

## Classifications

Each type of artifact falls into one of the following broad classes, which can often dictate how they're handled:

**Common-class:** There are many examples of this artifact, or it can be easily crafted from an artifact. Their effects are fairly simple or mundane.

**Uncommon-class:** While not impossible to obtain, uncommon-class artifacts are hard to come by, and sell for high prices. Their effects can vary from moderately impactful, to extremely dangerous or destructive if misused.

**Rare-class:** While multiples of some rare-class artifacts do exist, the exact number could be counted on one hand. The sale of these is regulated on a case-by-case basis, as some have the capacity to tip the balance of power between nations.

**Nocturne-class:** These artifacts, for whatever reason, cannot be recovered or sold by the Mountaineer's Guild. Some are immovable, while others have been bound to an individual's body - the exact circumstances vary.

**Restricted:** This is a special class, reserved only for artifacts that actively cause harm, and are therefore illegal to possess. Being caught in possession of a restricted artifact can come with steep fines and punishments.

:question: **TODO:** Empty


## Glowstone

Class: Common
Sell Price: 2az each
Skill Points: 1 each, max 10 per climb
Carry Slots: 1 per 10 stones

A a kind of semi precious gemstone which, when a small amount of pressure is applied, produces a bright green glow; excessive pressure can cause an explosion. Since this can be used as a light source that doesn't produce heat, glowstone lanterns can be fashoned from these.

## Sparkstone

:question: **TODO:** Empty

# Skill Point Tables

During your campaign, your characters can learn new skills by allocating unused skill points towards them. Each known skill has a level (starting at 1), the effects of the skill may change drastically depending on the given level. You can only gain a new level of a skill if you meet that skill level's prerequisites as listed, as well as having all previous levels of that skill. To purchase a new level in a skill, allocate unused skill points equal to that level towards that skill.

## Progression Skills

| Name | Prerequisites | Effect |
| --- | --- | --- |
| Health Up | - | Increase your maximum Health attribute by 2 for each level in this skill. |
| Stamina Up | - | Increase your maximum Stamina attribute by 1 for each level in this skill. |
| Fortitude Up | - | Increase your maximum Fortitude attribute by 1 for each level in this skill. |
| Obsession Up | - | Increase your maximum Obsession attribute by 1 for every level in this skill. |

## Survival Skills

:question: **TODO:** Empty

## Combat Skills

:question: **TODO:** Empty

## Craft Skills

:question: **TODO:** Empty - "crafts" are more like "professions"

## Group Skills

Group skills are unique, in that they are unusable and unobtainable unless everyone in the group allocates the required skill points.

:question: **TODO:** Empty

# Bestiary

:question: **TODO:** Empty

# Herbarium

:question: **TODO:** Empty

# Appendices

:question: **TODO:** Empty
